@@ -1,7 +1,7 @@
 /*
     Qalculate
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,8 +111,6 @@ extern bool rpn_mode, rpn_keypad_only;
 
 GtkTooltips *periodic_tooltips, *main_tooltips;
 
-extern GdkPixbuf *icon_pixbuf;
-
 extern vector<GtkWidget*> mode_items;
 extern vector<GtkWidget*> popup_result_mode_items;
 
@@ -276,18 +274,23 @@ void set_mode_items(const PrintOptions &po, const EvaluationOptions &eo, Assumpt
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_normal")), TRUE);
 			break;
 		}
-		case EXP_SCIENTIFIC: {
+		case EXP_BASE_3: {
 			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 1);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_engineering")), TRUE);
+			break;
+		}
+		case EXP_SCIENTIFIC: {
+			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 2);
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_scientific")), TRUE);
 			break;
 		}
 		case EXP_PURE: {
-			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 2);
+			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 3);
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_purely_scientific")), TRUE);
 			break;
 		}
 		case EXP_NONE: {
-			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 3);
+			if(initial_update) gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget (main_glade, "combobox_numerical_display")), 4);
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_non_scientific")), TRUE);
 			break;
 		}
@@ -296,6 +299,8 @@ void set_mode_items(const PrintOptions &po, const EvaluationOptions &eo, Assumpt
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_indicate_infinite_series")), po.indicate_infinite_series);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_show_ending_zeroes")), po.show_ending_zeroes);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_round_halfway_to_even")), po.round_halfway_to_even);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(main_glade, "menu_item_negative_exponents")), po.negative_exponents);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(main_glade, "menu_item_sort_minus_last")), po.sort_options.minus_last);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_display_prefixes")), po.use_unit_prefixes);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_all_prefixes")), po.use_all_prefixes);
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget (main_glade, "menu_item_denominator_prefixes")), po.use_denominator_prefix);
@@ -405,6 +410,9 @@ void create_main_window (void) {
 	expression = glade_xml_get_widget (main_glade, "expression");
 	resultview = glade_xml_get_widget (main_glade, "resultview");
 	historyview = glade_xml_get_widget (main_glade, "history");
+
+	//gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(historyview), TRUE);
+	
 	stackview = glade_xml_get_widget (main_glade, "stackview");
 	statuslabel_l = glade_xml_get_widget (main_glade, "label_status_left");
 	statuslabel_r = glade_xml_get_widget (main_glade, "label_status_right");
@@ -498,6 +506,15 @@ void create_main_window (void) {
 				prev_parse = false;
 				break;
 			}
+			case QALCULATE_HISTORY_REGISTER_MOVED: {
+				if(i != 0) {
+					gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "history_separator", NULL);
+				}
+				gtk_text_buffer_insert(tb, &iter, _("RPN Register Moved"), -1);
+				gtk_text_buffer_insert(tb, &iter, " ", -1);
+				prev_parse = false;
+				break;
+			}
 			case QALCULATE_HISTORY_TRANSFORMATION: {
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, inhistory[i].c_str(), -1, "history_transformation", NULL);
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ":  ", -1, "history_transformation", NULL);
@@ -525,13 +542,35 @@ void create_main_window (void) {
 				prev_parse = false;
 				break;
 			}
-			case QALCULATE_HISTORY_PARSE: {
+			case QALCULATE_HISTORY_PARSE_WITHEQUALS: {
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, " ", -1, "history_parse", NULL);
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, inhistory[i].c_str(), -1, "history_parse", NULL);
 				gtk_text_buffer_insert(tb, &iter, "\n", -1);
 				prev_parse = true;
 				break;
 			}
+			case QALCULATE_HISTORY_PARSE: {
+				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "  = ", -1, "history_parse", NULL);
+				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, inhistory[i].c_str(), -1, "history_parse", NULL);
+				gtk_text_buffer_insert(tb, &iter, "\n", -1);
+				prev_parse = true;
+				break;
+			}
+			case QALCULATE_HISTORY_PARSE_APPROXIMATE: {
+				string str = "  ";
+				if(printops.use_unicode_signs && can_display_unicode_string_function(SIGN_ALMOST_EQUAL, (void*) historyview)) {
+					str += SIGN_ALMOST_EQUAL " ";
+				} else {
+					str += "= ";
+					str += _("approx.");
+					str += " ";
+				}
+				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str.c_str(), -1, "history_parse", NULL);
+				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, inhistory[i].c_str(), -1, "history_parse", NULL);
+				gtk_text_buffer_insert(tb, &iter, "\n", -1);
+				prev_parse = true;
+				break;
+			}
 			case QALCULATE_HISTORY_WARNING: {
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "- ", -1, "history_warning", NULL);
 				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, inhistory[i].c_str(), -1, "history_warning", NULL);
@@ -550,8 +589,7 @@ void create_main_window (void) {
 				prev_parse = false;
 				break;
 			}
-		}
-		
+		}		
 	}
 
 	stackstore = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
@@ -634,10 +672,6 @@ void create_main_window (void) {
 	if(show_history || show_keypad || (show_stack && rpn_mode)) gtk_window_resize(GTK_WINDOW(glade_xml_get_widget(main_glade, "main_window")), 1, 1);
 	else gtk_window_resize(GTK_WINDOW(glade_xml_get_widget(main_glade, "main_window")), win_width, 1);
 
-#ifndef HAVE_LIBGNOMEUI
-	gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (main_glade, "main_window")), icon_pixbuf);
-#endif
-
 	update_status_text();
 	
 }
@@ -690,9 +724,6 @@ get_functions_dialog (void)
 
 		update_functions_tree();
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (functions_glade, "functions_dialog")), icon_pixbuf);
-#endif
 	}
 
 	return glade_xml_get_widget (functions_glade, "functions_dialog");
@@ -748,10 +779,6 @@ get_variables_dialog (void)
 
 		update_variables_tree();
 
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (variables_glade, "variables_dialog")), icon_pixbuf);
-#endif
-
 	}
 	
 	return glade_xml_get_widget (variables_glade, "variables_dialog");
@@ -818,10 +845,6 @@ get_units_dialog (void)
 		gtk_entry_set_alignment(GTK_ENTRY(glade_xml_get_widget (units_glade, "units_entry_from_val")), 1.0);
 		gtk_entry_set_alignment(GTK_ENTRY(glade_xml_get_widget (units_glade, "units_entry_to_val")), 1.0);
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (units_glade, "units_dialog")), icon_pixbuf);
-#endif
-	
 	}
 	
 	return glade_xml_get_widget (units_glade, "units_dialog");
@@ -883,10 +906,6 @@ get_datasets_dialog (void)
 
 		update_datasets_tree();
 
-#ifndef HAVE_LIBGNOMEUI		
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (datasets_glade, "datasets_dialog")), icon_pixbuf);
-#endif
-		
 	}
 
 	return glade_xml_get_widget (datasets_glade, "datasets_dialog");
@@ -1538,10 +1557,6 @@ get_nbases_dialog (void)
 		
 		glade_xml_signal_autoconnect(nbases_glade);
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (nbases_glade, "nbases_dialog")), icon_pixbuf);
-#endif
-	
 	}
 
 	return glade_xml_get_widget (nbases_glade, "nbases_dialog");
@@ -1583,10 +1598,6 @@ GtkWidget* get_about_dialog (void) {
 		
 		glade_xml_signal_autoconnect(about_glade);
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (about_glade, "about_dialog")), icon_pixbuf);
-#endif
-	
 	}
 
 	return glade_xml_get_widget (about_glade, "about_dialog");
@@ -1655,10 +1666,6 @@ GtkWidget* get_plot_dialog (void) {
 
 		glade_xml_signal_autoconnect(plot_glade);
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (plot_glade, "plot_dialog")), icon_pixbuf);
-#endif
-	
 	}
 		
 	return glade_xml_get_widget (plot_glade, "plot_dialog");		
@@ -1877,10 +1884,6 @@ GtkWidget* get_periodic_dialog (void) {
 			}
 		}
 		
-#ifndef HAVE_LIBGNOMEUI
-		gtk_window_set_icon(GTK_WINDOW(glade_xml_get_widget (periodictable_glade, "periodic_dialog")), icon_pixbuf);
-#endif
-	
 	}
 
 	return glade_xml_get_widget (periodictable_glade, "periodic_dialog");
